#!/bin/env python3

import os
import numpy as np
import time


def get_grads_and_hessians(graddir, hessdir, outfile, depth=0):

    # Find for which events I have found both
    gradfiles = os.listdir(graddir)
    hessfiles = os.listdir(hessdir)
    cmtfiles = list(set(gradfiles).intersection(set(hessfiles)))

    # Number events
    N = len(cmtfiles)

    if depth == 0:
        # Initialize arrays
        G = np.zeros((N, 10))
        H = np.zeros((N, 10, 10))
        Mg = 10
        Mh = 100
        RS = 10,10
    else:
        # Initialize arrays
        G = np.zeros((N, 2))
        H = np.zeros((N, 2, 2))
        Mg = 2
        Mh = 4
        RS = 2,2
    G[:] = np.nan
    H[:] = np.nan

    print(f"Total of {N} CMT files found with in the intersection.")
    time.sleep(2.0)

    counter = 0
    for _i, file in enumerate(cmtfiles):

        # Print progress
        print(f"{100*(_i+1)/N:3.0f} % -- {file[:-4]:16} -- {counter:{len(str(N))}d}", end='\r')

        # Get file locations
        gfile = os.path.join(graddir, file)
        hfile = os.path.join(hessdir, file)

        # Load gradient and hessian
        g = np.loadtxt(gfile)
        h = np.loadtxt(hfile)

        if (len(g) != Mg) or (len(h) != Mh) or (np.sum(g) == 0) or (np.sum(h) == 0):
            continue
        else:
            G[_i, :] = g
            H[_i, :, : ] = h.reshape(*RS)
            counter += 1
            
    print(f"{'Done':40s}")

    # Check which events are nan
    nanfilter = np.sum(~np.isnan(G), axis=1)

    
    # Fix matrices
    pos = np.where(nanfilter)[0]
    print("Events found: ", len(pos))
    H = H[pos, :,:]
    G = G[pos, :]

    # Get events
    cmts = np.array([_f[:-4] for _f in cmtfiles])
    cmts = cmts[pos]

    # Save
    np.savez(outfile, events=cmts, G=G, H=H)



if __name__ == "__main__":

    
    import sys
    if len(sys.argv) == 1:
        print("Use like so: python collect_grad_hess.py <graddir> <hessdir> <outfile> <depth(0,1)>")

    else:
        graddir = sys.argv[1]
        hessdir = sys.argv[2]
        outfile = sys.argv[3]
        depth = sys.argv[4]
        get_grads_and_hessians(graddir, hessdir, outfile, depth)

    sys.exit()
